@@ -6,17 +6,23 @@ pub use crate::common::Error;
 pub use crate::common::Result;
 use ::proc_macro2::TokenStream;
 
-pub fn test_case_impl(stream: TokenStream) -> TokenStream {
-    match build_test_case(stream) {
+pub fn it_impl(stream: TokenStream) -> TokenStream {
+    test_case_impl(stream, &"it")
+}
+
+pub fn test_impl(stream: TokenStream) -> TokenStream {
+    test_case_impl(stream, &"test")
+}
+
+fn test_case_impl(stream: TokenStream, prefix: &'static str) -> TokenStream {
+    let result = grammar::parse(stream).map(|ast| output::build(ast, prefix));
+
+    match result {
         Ok(output) => output,
         Err(err) => panic!("{}", err),
     }
 }
 
-fn build_test_case(stream: TokenStream) -> Result<TokenStream> {
-    grammar::parse(stream).map(output::build)
-}
-
 #[cfg(test)]
 mod test_case_impl {
     use super::*;
@@ -24,9 +30,25 @@ mod test_case_impl {
     use ::quote::quote;
 
     #[test]
-    fn it_should_provide_test_description_and_function() {
-        let output = test_case_impl(quote! {
-          "it should do blah and not foo", test_foo_blah
+    fn it_should_provide_test_description_and_function_for_test() {
+        let output = test_impl(quote! {
+          "should do blah and not foo", test_foo_blah
+        });
+
+        let expected = quote! {
+          #[test]
+          fn test_should_do_blah_and_not_foo() {
+            test_foo_blah()
+          }
+        };
+
+        assert_eq!(output.to_string(), expected.to_string());
+    }
+
+    #[test]
+    fn it_should_provide_test_description_and_function_for_it() {
+        let output = it_impl(quote! {
+          "should do blah and not foo", test_foo_blah
         });
 
         let expected = quote! {
@@ -38,20 +60,4 @@ mod test_case_impl {
 
         assert_eq!(output.to_string(), expected.to_string());
     }
-
-    #[test]
-    fn it_should_prefix_test_with_an_underscore_when_identifier_starts_with_a_number() {
-        let output = test_case_impl(quote! {
-          "123 abc", test_foo_blah
-        });
-
-        let expected = quote! {
-          #[test]
-          fn _123_abc() {
-            test_foo_blah()
-          }
-        };
-
-        assert_eq!(output.to_string(), expected.to_string());
-    }
 }
